'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
Object.defineProperty(exports, 'ComboBoxMenuItem', {
  enumerable: true,
  get: function () {
    return ComboBoxMenuItem;
  },
});
const _interop_require_wildcard = require('@swc/helpers/_/_interop_require_wildcard');
const _react = /*#__PURE__*/ _interop_require_wildcard._(require('react'));
const _index = require('../../utils/index.js');
const _helpers = require('./helpers.js');
const _ListItem = require('../List/ListItem.js');
const ComboBoxMenuItem = _react.memo(
  _react.forwardRef((props, forwardedRef) => {
    let {
      children,
      isSelected,
      disabled,
      value,
      onClick,
      sublabel,
      size = !!sublabel ? 'large' : 'default',
      startIcon,
      endIcon,
      role = 'option',
      index,
      ...rest
    } = props;
    let { focusedIndex, enableVirtualization } = (0, _index.useSafeContext)(
      _helpers.ComboBoxStateContext,
    );
    let focusRef = (el) => {
      if (!enableVirtualization && focusedIndex === index)
        el?.scrollIntoView({
          block: 'nearest',
        });
    };
    let refs = (0, _index.useMergedRefs)(forwardedRef, focusRef);
    return _react.createElement(
      _ListItem.ListItem,
      {
        as: 'div',
        actionable: true,
        size: size,
        active: isSelected,
        disabled: disabled,
        focused: focusedIndex === index,
        ref: refs,
        onClick: () => onClick?.(),
        role: role,
        tabIndex: 'presentation' === role ? void 0 : -1,
        'aria-selected': isSelected,
        'aria-disabled': disabled,
        'data-iui-index': index,
        ...rest,
      },
      startIcon &&
        _react.createElement(
          _ListItem.ListItem.Icon,
          {
            as: 'span',
            'aria-hidden': true,
          },
          startIcon,
        ),
      _react.createElement(
        _ListItem.ListItem.Content,
        null,
        children,
        sublabel &&
          _react.createElement(_ListItem.ListItem.Description, null, sublabel),
      ),
      endIcon ||
        (isSelected &&
          _react.createElement(
            _ListItem.ListItem.Icon,
            {
              as: 'span',
              'aria-hidden': true,
            },
            endIcon ?? _react.createElement(_index.SvgCheckmark, null),
          )),
    );
  }),
);
if ('development' === process.env.NODE_ENV)
  ComboBoxMenuItem.displayName = 'ComboBoxMenuItem';
