'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
Object.defineProperty(exports, 'DateRangeFilter', {
  enumerable: true,
  get: function () {
    return DateRangeFilter;
  },
});
const _interop_require_wildcard = require('@swc/helpers/_/_interop_require_wildcard');
const _react = /*#__PURE__*/ _interop_require_wildcard._(require('react'));
const _index = require('../../../../utils/index.js');
const _FilterButtonBar = require('../FilterButtonBar.js');
const _BaseFilter = require('../BaseFilter.js');
const _DatePickerInput = require('./DatePickerInput.js');
const defaultStrings = {
  from: 'From',
  to: 'To',
};
const defaultFormatDate = (date) => {
  let formatter = new Intl.DateTimeFormat('en-us', {
    month: 'short',
    day: 'numeric',
    year: 'numeric',
  });
  return formatter.format(date);
};
const defaultParseInput = (text) => {
  if (/^[a-z]{3}\s\d{1,2},\s\d{4}$/gi.test(text)) return new Date(text);
  return new Date('');
};
const DateRangeFilter = (props) => {
  let {
    column,
    translatedLabels,
    setFilter,
    clearFilter,
    formatDate = defaultFormatDate,
    parseInput = defaultParseInput,
    placeholder = 'MMM dd, yyyy',
    showYearSelection,
  } = props;
  (0, _index.useGlobals)();
  let translatedStrings = {
    ...defaultStrings,
    ...translatedLabels,
  };
  let [from, setFrom] = _react.useState(
    column.filterValue?.[0] ? new Date(column.filterValue?.[0]) : void 0,
  );
  let inputRef = _react.useRef(null);
  _react.useEffect(() => {
    if (inputRef.current) inputRef.current.focus();
  }, []);
  let onFromChange = _react.useCallback((date) => {
    setFrom((prevDate) => {
      if (prevDate || !date) return date;
      return new Date(
        date.getFullYear(),
        date.getMonth(),
        date.getDate(),
        0,
        0,
        0,
        0,
      );
    });
  }, []);
  let [to, setTo] = _react.useState(
    column.filterValue?.[1] ? new Date(column.filterValue?.[1]) : void 0,
  );
  let onToChange = _react.useCallback((date) => {
    setTo((prevDate) => {
      if (prevDate || !date) return date;
      return new Date(
        date.getFullYear(),
        date.getMonth(),
        date.getDate(),
        23,
        59,
        59,
        999,
      );
    });
  }, []);
  return _react.createElement(
    _BaseFilter.BaseFilter,
    {
      onSubmit: () => setFilter([from, to]),
    },
    _react.createElement(_DatePickerInput.DatePickerInput, {
      ref: inputRef,
      label: translatedStrings.from,
      date: from,
      onChange: onFromChange,
      formatDate: formatDate,
      parseInput: parseInput,
      placeholder: placeholder,
      selectedDate: to,
      isFromOrTo: 'from',
      localizedNames: translatedStrings.datePicker,
      showYearSelection: showYearSelection,
    }),
    _react.createElement(_DatePickerInput.DatePickerInput, {
      label: translatedStrings.to,
      date: to,
      onChange: onToChange,
      formatDate: formatDate,
      parseInput: parseInput,
      placeholder: placeholder,
      selectedDate: from,
      isFromOrTo: 'to',
      localizedNames: translatedStrings.datePicker,
      showYearSelection: showYearSelection,
    }),
    _react.createElement(_FilterButtonBar.FilterButtonBar, {
      clearFilter: clearFilter,
      translatedLabels: translatedLabels,
    }),
  );
};
