'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
Object.defineProperty(exports, 'defaultFilterFunctions', {
  enumerable: true,
  get: function () {
    return defaultFilterFunctions;
  },
});
const text = (rows, ids, filterValue) => {
  rows = rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return String(rowValue)
        .toLowerCase()
        .includes(String(filterValue).toLowerCase());
    }),
  );
  return rows;
};
text.autoRemove = (val) => !val;
const exactText = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return void 0 !== rowValue
        ? String(rowValue).toLowerCase() === String(filterValue).toLowerCase()
        : true;
    }),
  );
exactText.autoRemove = (val) => !val;
const exactTextCase = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return void 0 !== rowValue
        ? String(rowValue) === String(filterValue)
        : true;
    }),
  );
exactTextCase.autoRemove = (val) => !val;
const includes = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return rowValue.includes(filterValue);
    }),
  );
includes.autoRemove = (val) => !val || !val.length;
const includesAll = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return (
        rowValue &&
        rowValue.length &&
        filterValue.every((val) => rowValue.includes(val))
      );
    }),
  );
includesAll.autoRemove = (val) => !val || !val.length;
const includesSome = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return (
        rowValue &&
        rowValue.length &&
        filterValue.some((val) => rowValue.includes(val))
      );
    }),
  );
includesSome.autoRemove = (val) => !val || !val.length;
const includesValue = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return filterValue.includes(rowValue);
    }),
  );
includesValue.autoRemove = (val) => !val || !val.length;
const exact = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return rowValue === filterValue;
    }),
  );
exact.autoRemove = (val) => void 0 === val;
const equals = (rows, ids, filterValue) =>
  rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return rowValue == filterValue;
    }),
  );
equals.autoRemove = (val) => null == val;
const between = (rows, ids, filterValue) => {
  let [min, max] = filterValue || [];
  min = 'number' == typeof min ? min : -1 / 0;
  max = 'number' == typeof max ? max : 1 / 0;
  if (min > max) {
    let temp = min;
    min = max;
    max = temp;
  }
  return rows.filter((row) =>
    ids.some((id) => {
      let rowValue = row.values[id];
      return rowValue >= min && rowValue <= max;
    }),
  );
};
between.autoRemove = (val) =>
  !val || ('number' != typeof val[0] && 'number' != typeof val[1]);
const defaultFilterFunctions = {
  text,
  exactText,
  exactTextCase,
  includes,
  includesAll,
  includesSome,
  includesValue,
  between,
};
