import * as React from 'react';
import cx from 'classnames';
import { Box, ButtonBase } from '../../utils/index.js';
import { getColorValue } from './ColorPicker.js';
import { VisuallyHidden } from '../VisuallyHidden/VisuallyHidden.js';
export const ColorSwatch = React.forwardRef((props, ref) => {
  let { color, style, onClick, isActive, className, ...rest } = props;
  let colorString = React.useMemo(
    () =>
      'string' == typeof color ? color : getColorValue(color).toHslString(true),
    [color],
  );
  return React.createElement(
    Box,
    {
      as: onClick ? ButtonBase : 'span',
      className: cx(
        'iui-color-swatch',
        {
          'iui-active': isActive,
        },
        className,
      ),
      style: {
        '--iui-color-swatch-background': colorString,
        ...style,
      },
      onClick: onClick,
      'aria-pressed': !!onClick && isActive ? 'true' : void 0,
      ref: ref,
      ...rest,
    },
    props.children ??
      React.createElement(VisuallyHidden, null, colorString.toUpperCase()),
  );
});
if ('development' === process.env.NODE_ENV)
  ColorSwatch.displayName = 'ColorSwatch';
