import cx from 'classnames';
import * as React from 'react';
import { IconButton } from '../Buttons/IconButton.js';
import { SvgMoreVertical, Box } from '../../utils/index.js';
import { DropdownMenu } from '../DropdownMenu/DropdownMenu.js';
let defaultTranslations = {
  moreOptions: 'More options',
};
export const Header = React.forwardRef((props, forwardedRef) => {
  let {
    appLogo,
    breadcrumbs,
    isSlim = false,
    actions,
    menuItems,
    translatedStrings,
    className,
    children,
    ...rest
  } = props;
  let headerTranslations = {
    ...defaultTranslations,
    ...translatedStrings,
  };
  return React.createElement(
    Box,
    {
      as: 'header',
      className: cx('iui-page-header', className),
      'data-iui-size': isSlim ? 'slim' : void 0,
      ref: forwardedRef,
      ...rest,
    },
    React.createElement(
      Box,
      {
        className: 'iui-page-header-left',
      },
      appLogo,
      breadcrumbs &&
        React.createElement(Box, {
          className: 'iui-page-header-divider',
        }),
      breadcrumbs,
    ),
    children &&
      React.createElement(
        Box,
        {
          className: 'iui-page-header-center',
        },
        children,
      ),
    React.createElement(
      Box,
      {
        className: 'iui-page-header-right',
      },
      actions,
      menuItems &&
        React.createElement(
          DropdownMenu,
          {
            menuItems: menuItems,
          },
          React.createElement(
            IconButton,
            {
              styleType: 'borderless',
              'aria-label': headerTranslations.moreOptions,
            },
            React.createElement(SvgMoreVertical, {
              'aria-hidden': true,
            }),
          ),
        ),
    ),
  );
});
if ('development' === process.env.NODE_ENV) Header.displayName = 'Header';
