import * as React from 'react';
import { SvgCalendar, isBefore, useId } from '../../../../utils/index.js';
import { DatePicker } from '../../../DatePicker/DatePicker.js';
import { InputGrid } from '../../../InputGrid/InputGrid.js';
import { Label } from '../../../Label/Label.js';
import { InputWithDecorations } from '../../../InputWithDecorations/InputWithDecorations.js';
import { Popover } from '../../../Popover/Popover.js';
export const DatePickerInput = React.forwardRef((props, forwardedRef) => {
  let uid = useId();
  let {
    onChange,
    date,
    parseInput,
    formatDate,
    label,
    required,
    disabled,
    isFromOrTo,
    selectedDate,
    wrapperProps,
    labelProps,
    inputWrapperProps,
    id = uid,
    localizedNames,
    showYearSelection,
    ...rest
  } = props;
  let isDateDisabled = (date) => {
    if ('to' === isFromOrTo) return isBefore(date, selectedDate);
    return isBefore(selectedDate, date);
  };
  let buttonRef = React.useRef(null);
  let [inputValue, setInputValue] = React.useState('');
  React.useEffect(() => {
    if (date && !isNaN(date.valueOf())) setInputValue(formatDate(date));
  }, [date, formatDate]);
  let [isVisible, setIsVisible] = React.useState(false);
  let close = React.useCallback(() => setIsVisible(false), []);
  let onDateSelected = React.useCallback(
    (date) => {
      onChange(date);
      close();
      buttonRef.current?.focus();
    },
    [close, onChange],
  );
  let onInputChange = React.useCallback(
    (event) => {
      let value = event.target.value;
      setInputValue(value);
      if (!value) onChange(void 0);
      let parsedDate = parseInput(value);
      if (parsedDate && !isNaN(parsedDate.valueOf())) onChange(parsedDate);
    },
    [onChange, parseInput],
  );
  return React.createElement(
    InputGrid,
    {
      labelPlacement: 'inline',
      ...wrapperProps,
    },
    React.createElement(
      Label,
      {
        as: 'label',
        required: required,
        disabled: disabled,
        htmlFor: id,
        ...labelProps,
      },
      label,
    ),
    React.createElement(
      InputWithDecorations,
      inputWrapperProps,
      React.createElement(InputWithDecorations.Input, {
        id: id,
        value: inputValue,
        onChange: onInputChange,
        required: required,
        disabled: disabled,
        ref: forwardedRef,
        ...rest,
      }),
      React.createElement(
        Popover,
        {
          content: React.createElement(DatePicker, {
            date: date,
            onChange: onDateSelected,
            setFocus: true,
            isDateDisabled: isDateDisabled,
            localizedNames: localizedNames,
            applyBackground: false,
            showDatesOutsideMonth: false,
            showYearSelection: showYearSelection,
          }),
          placement: 'bottom-end',
          visible: isVisible,
          onVisibleChange: setIsVisible,
          closeOnOutsideClick: true,
          applyBackground: true,
        },
        React.createElement(
          InputWithDecorations.Button,
          {
            'aria-label': 'Date picker',
            ref: buttonRef,
          },
          React.createElement(SvgCalendar, null),
        ),
      ),
    ),
  );
});
