import * as React from 'react';
import cx from 'classnames';
import {
  useGlobals,
  SvgFilterHollow,
  SvgFilter,
} from '../../../utils/index.js';
import { IconButton } from '../../Buttons/IconButton.js';
import { Popover } from '../../Popover/Popover.js';
export const FilterToggle = (props) => {
  let { column, className, ...rest } = props;
  useGlobals();
  let [isVisible, setIsVisible] = React.useState(false);
  let close = React.useCallback(() => setIsVisible(false), []);
  let setFilter = React.useCallback(
    (filterValue) => {
      column.setFilter(filterValue);
      close();
    },
    [close, column],
  );
  let clearFilter = React.useCallback(() => {
    column.setFilter(void 0);
    close();
  }, [close, column]);
  let isColumnFiltered =
    null != column.filterValue && '' !== column.filterValue;
  return React.createElement(
    React.Fragment,
    null,
    column.canFilter &&
      column.Filter &&
      React.createElement(
        Popover,
        {
          content: column.render('Filter', {
            close,
            setFilter,
            clearFilter,
          }),
          placement: 'bottom-start',
          visible: isVisible,
          onVisibleChange: setIsVisible,
          closeOnOutsideClick: true,
          applyBackground: true,
        },
        React.createElement(
          IconButton,
          {
            styleType: 'borderless',
            isActive: isVisible || isColumnFiltered,
            className: cx('iui-table-filter-button', className),
            'aria-label': 'Filter',
            onClick: (e) => {
              e.stopPropagation();
            },
            'data-iui-shift': 'left',
            ...rest,
          },
          isColumnFiltered
            ? React.createElement(SvgFilter, null)
            : React.createElement(SvgFilterHollow, null),
        ),
      ),
  );
};
