import * as React from 'react';
import { defaultFilterFunctions } from '../filters/defaultFilterFunctions.js';
export const useSubRowFiltering = (hasAnySubRows) => (hooks) => {
  hooks.useInstance.push(useInstance.bind({}, hasAnySubRows));
};
let useInstance = (hasAnySubRows, instance) => {
  let setInitialSubRows = (rows) => {
    rows.forEach((row) => {
      if (!row.initialSubRows) row.initialSubRows = row.subRows;
      setInitialSubRows(row.subRows);
    });
  };
  setInitialSubRows(instance.initialRows);
  let {
    filteredRows = instance.filteredRows,
    filteredFlatRows = instance.filteredFlatRows,
    filteredRowsById = instance.filteredRowsById,
  } = React.useMemo(() => {
    if (!hasAnySubRows) return {};
    let setSubRows = (rows) => {
      rows.forEach((row) => {
        row.subRows = row.initialSubRows ?? [];
        setSubRows(row.subRows);
      });
    };
    setSubRows(instance.initialRows);
    let currentlyFilteredRows = [...instance.initialRows];
    instance.state.filters.forEach(({ id: columnId, value: filterValue }) => {
      let column = instance.allColumns.find((c) => c.id === columnId);
      if (!column) return;
      let filterTypes = {
        ...defaultFilterFunctions,
        ...instance.filterTypes,
      };
      let filterFn =
        'function' == typeof column.filter
          ? column.filter
          : filterTypes[column.filter ?? 'text'];
      currentlyFilteredRows = currentlyFilteredRows.filter((row) =>
        handleRowFiltering(row, filterFn, columnId, filterValue),
      );
    });
    let filteredRows = [];
    let filteredFlatRows = [];
    let filteredRowsById = {};
    let populateRows = (row) => {
      if (0 === row.depth) filteredRows.push(row);
      filteredFlatRows.push(row);
      filteredRowsById[row.id] = row;
      if (row.subRows.length) row.subRows.forEach((r) => populateRows(r));
    };
    currentlyFilteredRows.forEach((row) => populateRows(row));
    return {
      filteredRows,
      filteredFlatRows,
      filteredRowsById,
    };
  }, [
    instance.allColumns,
    instance.filterTypes,
    instance.initialRows,
    instance.state.filters,
    hasAnySubRows,
  ]);
  Object.assign(instance, {
    filteredRows,
    filteredFlatRows,
    filteredRowsById,
    rows: filteredRows,
    flatRows: filteredFlatRows,
    rowsById: filteredRowsById,
  });
};
let handleRowFiltering = (row, filterFn, columnId, filterValue) => {
  let hasFilteredSubRows = false;
  row.subRows = row.initialSubRows.filter((subRow) => {
    let result = handleRowFiltering(subRow, filterFn, columnId, filterValue);
    if (result) hasFilteredSubRows = true;
    return result;
  });
  if (hasFilteredSubRows) return true;
  let result = filterFn([row], [columnId], filterValue);
  return !!result.length;
};
