import * as React from 'react';
import { IconButton } from '../Buttons/IconButton.js';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type ColorInputPanelProps = {
    /**
     * The default color format to be inputted in the panel.
     */
    defaultColorFormat: 'hsl' | 'rgb' | 'hex';
    /**
     * Color formats to switch between. The swap button will cycle between these formats.
     *
     * If array only has one option, then swap button will not be shown.
     *
     * @default ['hsl', 'rgb', 'hex']
     */
    allowedColorFormats?: ('hsl' | 'rgb' | 'hex')[];
    /**
     * Passes props to the color picker section label.
     */
    panelLabelProps?: React.ComponentProps<'div'>;
    /**
     * Passes props to the color input container.
     */
    colorInputContainerProps?: React.ComponentProps<'div'>;
    /**
     * Passes props to the color input fields group.
     */
    inputFieldsGroupProps?: React.ComponentProps<'div'>;
    /**
     * Passes props to the swap color format button.
     */
    swapColorFormatButtonProps?: React.ComponentProps<typeof IconButton>;
};
/**
 * `ColorInputPanel` shows input fields to enter precise color values in the specified format.
 * It also allows switching between the specified formats using a swap button.
 * @example
 * <ColorPicker>
 *   // ...
 *   <ColorInputPanel defaultColorFormat='hsl' />
 * </ColorPicker>
 */
export declare const ColorInputPanel: PolymorphicForwardRefComponent<"div", ColorInputPanelProps>;
export {};
