'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
Object.defineProperty(exports, 'ColorInputPanel', {
  enumerable: true,
  get: function () {
    return ColorInputPanel;
  },
});
const _interop_require_default = require('@swc/helpers/_/_interop_require_default');
const _interop_require_wildcard = require('@swc/helpers/_/_interop_require_wildcard');
const _react = /*#__PURE__*/ _interop_require_wildcard._(require('react'));
const _classnames = /*#__PURE__*/ _interop_require_default._(
  require('classnames'),
);
const _IconButton = require('../Buttons/IconButton.js');
const _Input = require('../Input/Input.js');
const _index = require('../../utils/index.js');
const _ColorPickerContext = require('./ColorPickerContext.js');
const ColorInputPanel = _react.forwardRef((props, ref) => {
  let {
    defaultColorFormat,
    allowedColorFormats = ['hsl', 'rgb', 'hex'],
    className,
    colorInputContainerProps,
    panelLabelProps,
    inputFieldsGroupProps,
    swapColorFormatButtonProps,
    ...rest
  } = props;
  let inputsContainerRef = _react.useRef(null);
  let { activeColor, applyHsvColorChange, hsvColor, showAlpha } = (0,
  _ColorPickerContext.useColorPickerContext)();
  let [currentFormat, setCurrentFormat] = _react.useState(defaultColorFormat);
  _react.useEffect(() => {
    setCurrentFormat(defaultColorFormat);
  }, [defaultColorFormat]);
  let [input, setInput] = _react.useState(['', '', '', '']);
  _react.useEffect(() => {
    if ('hsl' === currentFormat) {
      let hsl = activeColor.toHslColor();
      setInput([
        _index.ColorValue.getFormattedColorNumber(hsvColor.h),
        _index.ColorValue.getFormattedColorNumber(hsl.s),
        _index.ColorValue.getFormattedColorNumber(hsl.l),
        _index.ColorValue.getFormattedColorNumber(
          hsl.a ?? activeColor.getAlpha() / 255,
          2,
        ),
      ]);
    } else if ('rgb' === currentFormat) {
      let rgb = activeColor.toRgbColor();
      setInput([
        rgb.r.toString(),
        rgb.g.toString(),
        rgb.b.toString(),
        _index.ColorValue.getFormattedColorNumber(
          rgb.a ?? activeColor.getAlpha() / 255,
          2,
        ),
      ]);
    } else {
      setInput([activeColor.toHexString(showAlpha)]);
      setValidHexInput(true);
    }
  }, [activeColor, hsvColor.h, currentFormat, showAlpha]);
  let [validHexInput, setValidHexInput] = _react.useState(true);
  let swapColorFormat = _react.useCallback(() => {
    let newFormat =
      allowedColorFormats[
        (allowedColorFormats.indexOf(currentFormat) + 1) %
          allowedColorFormats.length
      ] ?? allowedColorFormats[0];
    setCurrentFormat(newFormat);
  }, [currentFormat, allowedColorFormats]);
  let isFocusInside = (focused) =>
    !!(
      focused &&
      inputsContainerRef.current &&
      inputsContainerRef.current.contains(focused)
    );
  let handleColorInputChange = () => {
    let color;
    if ('hex' === currentFormat) {
      try {
        let value = input[0].replace(/ /g, '').toLowerCase();
        color = _index.ColorValue.create(value);
        setValidHexInput(true);
        if (activeColor.toHexString(showAlpha).toLowerCase() === value) return;
      } catch (_e) {
        setValidHexInput(false);
        return;
      }
    }
    if ('hsl' === currentFormat) {
      let [h, s, l, a] = input.map(Number);
      if (
        h < 0 ||
        h > 360 ||
        s < 0 ||
        s > 100 ||
        l < 0 ||
        l > 100 ||
        a < 0 ||
        a > 1
      )
        return;
      let hsl = activeColor.toHslColor();
      if (hsl.h === h && hsl.s === s && hsl.l === l && hsl.a === a) return;
      color = _index.ColorValue.create({
        h,
        s,
        l,
        a,
      });
    }
    if ('rgb' === currentFormat) {
      let [r, g, b, a] = input.map(Number);
      if (
        r < 0 ||
        r > 255 ||
        g < 0 ||
        g > 255 ||
        b < 0 ||
        b > 255 ||
        a < 0 ||
        a > 1
      )
        return;
      let rgb = activeColor.toRgbColor();
      if (rgb.r === r && rgb.g === g && rgb.b === b && rgb.a === a) return;
      color = _index.ColorValue.create({
        r,
        g,
        b,
        a,
      });
    }
    if (color) applyHsvColorChange(color.toHsvColor(), true, color);
  };
  let hexInputField = _react.createElement(_Input.Input, {
    size: 'small',
    maxLength: showAlpha ? 9 : 7,
    minLength: 1,
    placeholder: 'HEX',
    'aria-label': 'Hex',
    value: input[0],
    onChange: (event) => {
      let value = event.target.value.startsWith('#')
        ? event.target.value
        : `#${event.target.value}`;
      setInput([value]);
    },
    onKeyDown: (event) => {
      if ('Enter' === event.key) {
        event.preventDefault();
        handleColorInputChange();
      }
    },
    onBlur: (event) => {
      event.preventDefault();
      handleColorInputChange();
    },
    status: validHexInput ? void 0 : 'negative',
  });
  let hslInputs = _react.createElement(
    _react.Fragment,
    null,
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '359',
      step: '.1',
      placeholder: 'H',
      'aria-label': 'Hue',
      value: input[0] ?? '',
      onChange: (event) => {
        setInput([event.target.value, input[1], input[2], input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[0]) < 0 || Number(input[0]) > 360 ? 'negative' : void 0,
    }),
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '100',
      step: '.1',
      placeholder: 'S',
      'aria-label': 'Saturation',
      value: input[1] ?? '',
      onChange: (event) => {
        setInput([input[0], event.target.value, input[2], input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[1]) < 0 || Number(input[1]) > 100 ? 'negative' : void 0,
    }),
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '100',
      step: '.1',
      placeholder: 'L',
      'aria-label': 'Lightness',
      value: input[2] ?? '',
      onChange: (event) => {
        setInput([input[0], input[1], event.target.value, input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[2]) < 0 || Number(input[2]) > 100 ? 'negative' : void 0,
    }),
    showAlpha &&
      _react.createElement(_Input.Input, {
        size: 'small',
        type: 'number',
        min: '0',
        max: '1',
        step: '.01',
        placeholder: 'A',
        'aria-label': 'Alpha',
        value: input[3] ?? '',
        onChange: (event) => {
          setInput([input[0], input[1], input[2], event.target.value]);
        },
        onKeyDown: (event) => {
          if ('Enter' === event.key) {
            event.preventDefault();
            handleColorInputChange();
          }
        },
        onBlur: (event) => {
          event.preventDefault();
          if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
        },
        status:
          Number(input[3]) < 0 || Number(input[3]) > 1 ? 'negative' : void 0,
      }),
  );
  let rgbInputs = _react.createElement(
    _react.Fragment,
    null,
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '255',
      placeholder: 'R',
      'aria-label': 'Red',
      value: input[0] ?? '',
      onChange: (event) => {
        setInput([event.target.value, input[1], input[2], input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[0]) < 0 || Number(input[0]) > 255 ? 'negative' : void 0,
    }),
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '255',
      placeholder: 'G',
      'aria-label': 'Green',
      value: input[1] ?? '',
      onChange: (event) => {
        setInput([input[0], event.target.value, input[2], input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[1]) < 0 || Number(input[1]) > 255 ? 'negative' : void 0,
    }),
    _react.createElement(_Input.Input, {
      size: 'small',
      type: 'number',
      min: '0',
      max: '255',
      placeholder: 'B',
      'aria-label': 'Blue',
      value: input[2] ?? '',
      onChange: (event) => {
        setInput([input[0], input[1], event.target.value, input[3]]);
      },
      onKeyDown: (event) => {
        if ('Enter' === event.key) {
          event.preventDefault();
          handleColorInputChange();
        }
      },
      onBlur: (event) => {
        event.preventDefault();
        if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
      },
      status:
        Number(input[2]) < 0 || Number(input[2]) > 255 ? 'negative' : void 0,
    }),
    showAlpha &&
      _react.createElement(_Input.Input, {
        size: 'small',
        type: 'number',
        min: '0',
        max: '1',
        step: '.01',
        placeholder: 'A',
        'aria-label': 'Alpha',
        value: input[3] ?? '',
        onChange: (event) => {
          setInput([input[0], input[1], input[2], event.target.value]);
        },
        onKeyDown: (event) => {
          if ('Enter' === event.key) {
            event.preventDefault();
            handleColorInputChange();
          }
        },
        onBlur: (event) => {
          event.preventDefault();
          if (!isFocusInside(event.relatedTarget)) handleColorInputChange();
        },
        status:
          Number(input[3]) < 0 || Number(input[3]) > 1 ? 'negative' : void 0,
      }),
  );
  let fallbackLabelId = (0, _index.useId)();
  let labelId = panelLabelProps?.id ?? fallbackLabelId;
  return _react.createElement(
    _index.Box,
    {
      as: 'div',
      className: (0, _classnames.default)('iui-color-input-wrapper', className),
      ref: ref,
      ...rest,
    },
    _react.createElement(
      _index.Box,
      {
        as: 'div',
        ...panelLabelProps,
        className: (0, _classnames.default)(
          'iui-color-picker-section-label',
          panelLabelProps?.className,
        ),
        id: labelId,
      },
      showAlpha && 'hex' !== currentFormat
        ? currentFormat.toUpperCase() + 'A'
        : currentFormat.toUpperCase(),
    ),
    _react.createElement(
      _index.Box,
      {
        as: 'div',
        ...colorInputContainerProps,
        className: (0, _classnames.default)(
          'iui-color-input',
          colorInputContainerProps?.className,
        ),
      },
      allowedColorFormats.length > 1 &&
        _react.createElement(
          _IconButton.IconButton,
          {
            size: 'small',
            styleType: 'borderless',
            label: 'Switch format',
            ...swapColorFormatButtonProps,
            onClick: (0, _index.mergeEventHandlers)(
              swapColorFormatButtonProps?.onClick,
              swapColorFormat,
            ),
          },
          _react.createElement(_index.SvgSwap, null),
        ),
      _react.createElement(
        _index.Box,
        {
          as: 'div',
          role: 'hex' !== currentFormat ? 'group' : void 0,
          'aria-labelledby': 'hex' !== currentFormat ? labelId : void 0,
          ...inputFieldsGroupProps,
          ref: (0, _index.useMergedRefs)(
            inputsContainerRef,
            inputFieldsGroupProps?.ref,
          ),
          className: (0, _classnames.default)(
            'iui-color-input-fields',
            inputFieldsGroupProps?.className,
          ),
        },
        'hex' === currentFormat && hexInputField,
        'rgb' === currentFormat && rgbInputs,
        'hsl' === currentFormat && hslInputs,
      ),
    ),
  );
});
if ('development' === process.env.NODE_ENV)
  ColorInputPanel.displayName = 'ColorInputPanel';
