'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
function _export(target, all) {
  for (var name in all)
    Object.defineProperty(target, name, {
      enumerable: true,
      get: all[name],
    });
}
_export(exports, {
  ColorPicker: function () {
    return ColorPicker;
  },
  getColorValue: function () {
    return getColorValue;
  },
});
const _interop_require_default = require('@swc/helpers/_/_interop_require_default');
const _interop_require_wildcard = require('@swc/helpers/_/_interop_require_wildcard');
const _react = /*#__PURE__*/ _interop_require_wildcard._(require('react'));
const _index = require('../../utils/index.js');
const _classnames = /*#__PURE__*/ _interop_require_default._(
  require('classnames'),
);
const _ColorPickerContext = require('./ColorPickerContext.js');
const getColorValue = (color) => {
  if (color instanceof _index.ColorValue) return color;
  return _index.ColorValue.create(color);
};
const ColorPicker = _react.forwardRef((props, forwardedRef) => {
  let {
    children,
    className,
    selectedColor,
    onChange,
    onChangeComplete,
    showAlpha = false,
    applyBackground = true,
    ...rest
  } = props;
  let ref = _react.useRef(null);
  let inColor = _react.useMemo(
    () => getColorValue(selectedColor),
    [selectedColor],
  );
  let activeColorTbgr = _react.useRef(inColor.toTbgr());
  let [activeColor, setActiveColor] = _react.useState(inColor);
  _react.useEffect(() => {
    setActiveColor(inColor);
  }, [inColor]);
  let [hsvColor, setHsvColor] = _react.useState(() => activeColor.toHsvColor());
  _react.useEffect(() => {
    if (inColor.toTbgr() !== activeColorTbgr.current) {
      activeColorTbgr.current = inColor.toTbgr();
      setHsvColor(inColor.toHsvColor());
    }
  }, [inColor]);
  let applyHsvColorChange = _react.useCallback(
    (newColor, selectionChanged, newColorValue) => {
      setHsvColor(newColor);
      let newActiveColor = newColorValue ?? _index.ColorValue.create(newColor);
      if (selectionChanged) onChangeComplete?.(newActiveColor);
      else onChange?.(newActiveColor);
      activeColorTbgr.current = newActiveColor.toTbgr();
      setActiveColor(newActiveColor);
    },
    [onChange, onChangeComplete],
  );
  return _react.createElement(
    _index.Box,
    {
      className: (0, _classnames.default)(
        'iui-color-picker',
        {
          'iui-popover-surface': applyBackground,
        },
        className,
      ),
      ref: (0, _index.useMergedRefs)(ref, forwardedRef),
      ...rest,
    },
    _react.createElement(
      _ColorPickerContext.ColorPickerContext.Provider,
      {
        value: {
          activeColor,
          setActiveColor,
          hsvColor,
          applyHsvColorChange,
          onChangeComplete,
          showAlpha,
        },
      },
      children,
    ),
  );
});
if ('development' === process.env.NODE_ENV)
  ColorPicker.displayName = 'ColorPicker';
