import * as React from 'react';
import type { AnyString } from '../../utils/types.js';
import type { PolymorphicForwardRefComponent } from '../../utils/props.js';
export type IconProps = {
    /**
     * Size of the svg.
     *  - 'medium': works well with most text
     *  - 'small': smaller than medium
     *  - 'large': larger than medium
     *  - 'auto': scales with text
     *
     * Also accepts a custom string value that will be used unchanged.
     *
     * @default 'medium'
     */
    size?: 'auto' | 'small' | 'medium' | 'large' | AnyString;
    /**
     * Fill (color) of the svg.
     * Defaults to `--iui-color-icon-muted`. Can be specified to
     * use one of the status colors.
     *
     * Also accepts a custom string value that will be used unchanged.
     *
     * @default 'default'
     */
    fill?: 'default' | 'positive' | 'informational' | 'negative' | 'warning' | AnyString;
    /**
     * Option to add padding to the icon.
     * @default false
     */
    padded?: boolean;
} & React.ComponentPropsWithoutRef<'span'>;
/**
 * A utility component to provide size and fill to svgs.
 * Works well with svgs from `@itwin/itwinui-icons-react`.
 *
 * @example
 * <Icon>
 *   <SvgPlaceholder />
 * </Icon>
 *
 * @example
 * <Icon fill='negative'>
 *   <SvgStatusError />
 * </Icon>
 */
export declare const Icon: PolymorphicForwardRefComponent<"span", IconProps>;
