import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type InformationPanelProps = {
    /**
     * Is the panel open?
     * @default false
     */
    isOpen?: boolean;
    /**
     * Orientation of the panel.
     * @default 'vertical'
     */
    orientation?: 'vertical' | 'horizontal';
    /**
     * Set to false to make the panel non-resizable.
     * @default true
     */
    resizable?: boolean;
    /**
     * Content of the panel.
     */
    children?: React.ReactNode;
};
/**
 * InformationPanel provides a way to view additional content or attributes
 * without leaving the main content area (e.g. Table).
 *
 * The panel appears as an overlay on top of the main content.
 * @example
 * <InformationPanelWrapper>
 *   <Table ... /> // component to overlay
 *   <InformationPanel isOpen={true}>
 *     <InformationPanelHeader onClose={() => {}}>
 *       <Text variant='subheading'>InfoPanel heading</Text>
 *     </InformationPanelHeader>
 *     <InformationPanelBody>
 *       <Text>Metadata</Text>
 *       <InformationPanelContent ... />
 *       <Text>Attributes</Text>
 *       <InformationPanelContent ... />
 *     </InformationPanelBody>
 *   </InformationPanel>
 * </InformationPanelWrapper>
 */
export declare const InformationPanel: PolymorphicForwardRefComponent<"div", InformationPanelProps>;
export {};
