import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type ProgressRadialProps = {
    /**
     * Progress percentage. Should be a number between 0 and 100.
     */
    value?: number;
    /**
     * Progress variant. If true, value will be ignored.
     *
     * @default false if value is provided, true otherwise
     */
    indeterminate?: boolean;
    /**
     * Status of Progress. Positive status always has 100% value.
     */
    status?: 'positive' | 'negative' | 'warning';
    /**
     * Size of the progress indicator. Defaults to medium size.
     * @default ''
     */
    size?: '' | 'x-small' | 'small' | 'large';
    /**
     * Content shown inside progress indicator.
     */
    children?: React.ReactNode;
};
/**
 * Circular Progress Indicator
 * @example
 * Basic
 * <ProgressRadial value={50} />
 * Indeterminate
 * <ProgressRadial indeterminate />
 * // Positive / Negative / Warning
 * <ProgressRadial status='positive' />
 * <ProgressRadial status='negative' />
 * <ProgressRadial status='warning' />
 * Centered Content
 * <ProgressRadial value={63}>63</ProgressRadial>
 * Small
 * <ProgressRadial size={'small'} indeterminate/>
 */
export declare const ProgressRadial: PolymorphicForwardRefComponent<"div", ProgressRadialProps>;
export {};
