'use strict';
Object.defineProperty(exports, '__esModule', {
  value: true,
});
Object.defineProperty(exports, 'DatePickerInput', {
  enumerable: true,
  get: function () {
    return DatePickerInput;
  },
});
const _interop_require_wildcard = require('@swc/helpers/_/_interop_require_wildcard');
const _react = /*#__PURE__*/ _interop_require_wildcard._(require('react'));
const _index = require('../../../../utils/index.js');
const _DatePicker = require('../../../DatePicker/DatePicker.js');
const _InputGrid = require('../../../InputGrid/InputGrid.js');
const _Label = require('../../../Label/Label.js');
const _InputWithDecorations = require('../../../InputWithDecorations/InputWithDecorations.js');
const _Popover = require('../../../Popover/Popover.js');
const DatePickerInput = _react.forwardRef((props, forwardedRef) => {
  let uid = (0, _index.useId)();
  let {
    onChange,
    date,
    parseInput,
    formatDate,
    label,
    required,
    disabled,
    isFromOrTo,
    selectedDate,
    wrapperProps,
    labelProps,
    inputWrapperProps,
    id = uid,
    localizedNames,
    showYearSelection,
    ...rest
  } = props;
  let isDateDisabled = (date) => {
    if ('to' === isFromOrTo) return (0, _index.isBefore)(date, selectedDate);
    return (0, _index.isBefore)(selectedDate, date);
  };
  let buttonRef = _react.useRef(null);
  let [inputValue, setInputValue] = _react.useState('');
  _react.useEffect(() => {
    if (date && !isNaN(date.valueOf())) setInputValue(formatDate(date));
  }, [date, formatDate]);
  let [isVisible, setIsVisible] = _react.useState(false);
  let close = _react.useCallback(() => setIsVisible(false), []);
  let onDateSelected = _react.useCallback(
    (date) => {
      onChange(date);
      close();
      buttonRef.current?.focus();
    },
    [close, onChange],
  );
  let onInputChange = _react.useCallback(
    (event) => {
      let value = event.target.value;
      setInputValue(value);
      if (!value) onChange(void 0);
      let parsedDate = parseInput(value);
      if (parsedDate && !isNaN(parsedDate.valueOf())) onChange(parsedDate);
    },
    [onChange, parseInput],
  );
  return _react.createElement(
    _InputGrid.InputGrid,
    {
      labelPlacement: 'inline',
      ...wrapperProps,
    },
    _react.createElement(
      _Label.Label,
      {
        as: 'label',
        required: required,
        disabled: disabled,
        htmlFor: id,
        ...labelProps,
      },
      label,
    ),
    _react.createElement(
      _InputWithDecorations.InputWithDecorations,
      inputWrapperProps,
      _react.createElement(_InputWithDecorations.InputWithDecorations.Input, {
        id: id,
        value: inputValue,
        onChange: onInputChange,
        required: required,
        disabled: disabled,
        ref: forwardedRef,
        ...rest,
      }),
      _react.createElement(
        _Popover.Popover,
        {
          content: _react.createElement(_DatePicker.DatePicker, {
            date: date,
            onChange: onDateSelected,
            setFocus: true,
            isDateDisabled: isDateDisabled,
            localizedNames: localizedNames,
            applyBackground: false,
            showDatesOutsideMonth: false,
            showYearSelection: showYearSelection,
          }),
          placement: 'bottom-end',
          visible: isVisible,
          onVisibleChange: setIsVisible,
          closeOnOutsideClick: true,
          applyBackground: true,
        },
        _react.createElement(
          _InputWithDecorations.InputWithDecorations.Button,
          {
            'aria-label': 'Date picker',
            ref: buttonRef,
          },
          _react.createElement(_index.SvgCalendar, null),
        ),
      ),
    ),
  );
});
