import * as React from 'react';
import type { CommonProps } from '../../../utils/index.js';
export type FilterButtonBarTranslation = {
    filter: string;
    clear: string;
};
export type FilterButtonBarProps = {
    /**
     * Additional content that you want to be shown on the left of the buttons.
     */
    children?: React.ReactNode;
    /**
     * Callback used for Filter button click.
     *
     * @deprecated Use the onSubmit callback from `BaseFilter` instead.
     */
    setFilter?: () => void;
    /**
     * Callback used for Clear button click. Should come from `BaseFilter`.
     */
    clearFilter: () => void;
    /**
     * Localized strings used in buttons.
     */
    translatedLabels?: FilterButtonBarTranslation;
} & Omit<CommonProps, 'title'>;
/**
 * Button bar component that should be used in a filter. It already has Filter and Clear buttons.
 * @example
 * <FilterButtonBar setFilter={() => setFilter(text)} clearFilter={clearFilter} />
 */
export declare const FilterButtonBar: (props: FilterButtonBarProps) => React.JSX.Element;
