import type { PolymorphicForwardRefComponent } from '../../utils/props.js';
type VisuallyHiddenOwnProps = {
    /**
     * When VisuallyHidden is used with an interactive element (e.g. button),
     * that element will "unhide" (become visible again) when focused.
     *
     * @default true
     */
    unhideOnFocus?: boolean;
};
/**
 * Hides content visually but keeps it still accessible to screen readers
 * and other assistive technologies.
 *
 * @example
 * <div aria-hidden='true'>★★★☆☆</div>
 * <VisuallyHidden>3 stars out of 5</VisuallyHidden>
 *
 * @see https://www.scottohara.me/blog/2017/04/14/inclusively-hidden.html
 */
export declare const VisuallyHidden: PolymorphicForwardRefComponent<"span", VisuallyHiddenOwnProps>;
export {};
