import * as React from 'react';
import { ColorValue } from '../../utils/index.js';
import type { ColorType, PolymorphicForwardRefComponent } from '../../utils/index.js';
export type ColorPaletteProps = {
    /**
     * Label shown above the palette.
     */
    label?: React.ReactNode;
    /**
     * Passes props to the color picker section label.
     */
    labelProps?: React.ComponentProps<'div'>;
    /**
     * List of colors shown as swatches in the palette.
     */
    colors?: Array<ColorType | ColorValue>;
    /**
     * Pass any custom swatches as children.
     */
    children?: React.ReactNode;
    /**
     * Passes props to the color palette container.
     */
    paletteContainerProps?: React.ComponentProps<'div'>;
};
/**
 * `ColorPalette` is used to show a group of `ColorSwatch` components.
 * @example
 * <ColorPalette colors={['#ffffff', '#000000']} />
 * @example
 * <ColorPalette>
 *   <ColorSwatch color='#ffffff' />
 *   <ColorSwatch color='#000000' />
 *   // ...
 * </ColorPalette>
 */
export declare const ColorPalette: PolymorphicForwardRefComponent<"div", ColorPaletteProps>;
