import * as React from 'react';
import cx from 'classnames';
import { Box } from '../../utils/index.js';
import { getColorValue } from './ColorPicker.js';
import { ColorSwatch } from './ColorSwatch.js';
import { useColorPickerContext } from './ColorPickerContext.js';
export const ColorPalette = React.forwardRef((props, ref) => {
  let {
    colors,
    label,
    labelProps,
    className,
    children,
    paletteContainerProps,
    ...rest
  } = props;
  let { activeColor, setActiveColor, onChangeComplete } =
    useColorPickerContext();
  return React.createElement(
    Box,
    {
      className: cx('iui-color-palette-wrapper', className),
      ref: ref,
      ...rest,
    },
    label &&
      React.createElement(
        Box,
        {
          as: 'div',
          ...labelProps,
          className: cx(
            'iui-color-picker-section-label',
            labelProps?.className,
          ),
        },
        label,
      ),
    React.createElement(
      Box,
      {
        as: 'div',
        ...paletteContainerProps,
        className: cx('iui-color-palette', paletteContainerProps?.className),
      },
      children,
      colors &&
        colors.map((_color, index) => {
          let color = getColorValue(_color);
          return React.createElement(ColorSwatch, {
            key: index,
            color: color,
            onClick: () => {
              onChangeComplete?.(color);
              setActiveColor(color);
            },
            isActive: color.equals(activeColor),
          });
        }),
    ),
  );
});
if ('development' === process.env.NODE_ENV)
  ColorPalette.displayName = 'ColorPalette';
