import * as React from 'react';
import { ColorValue } from '../../utils/index.js';
import type { ColorType, PolymorphicForwardRefComponent } from '../../utils/index.js';
export declare const getColorValue: (color: ColorType | ColorValue | undefined) => ColorValue;
type ColorPickerProps = {
    /**
     * Content of the color palette.
     *
     * Pass a combination of `ColorBuilder`, `ColorInputPanel`, `ColorPalette`, and any custom children.
     */
    children: React.ReactNode;
    /**
     * The selected color within color picker.
     */
    selectedColor?: ColorType | ColorValue;
    /**
     * Callback fired when the color value is internally updated during
     * operations like dragging a thumb. Use this callback with caution as a
     * high-volume of updates will occur when dragging.
     */
    onChange?: (color: ColorValue) => void;
    /**
     * Callback fired when selectedColor is done changing.
     * This can be on pointerUp or keyUp when thumb is done dragging,
     * or when user clicks on color builder components, or when user clicks on color swatch.
     */
    onChangeComplete?: (color: ColorValue) => void;
    /**
     * If true, ColorBuilder will show the alpha slider and ColorInputPanel will show an alpha input.
     * @default false
     */
    showAlpha?: boolean;
    /**
     * Whether there is a background, border, shadow, etc.
     *
     * Should be set to true if used in a popover that doesn't have its own background,
     * or set to false if the popover has its own background or embedding within a page.
     *
     * @default true
     */
    applyBackground?: boolean;
};
/**
 * ColorPicker to display color builder options, color inputs, and a palette of ColorSwatches.
 * @example
 * <ColorPicker onChangeComplete={() => {}} selectedColor={activeColor}>
 *   <ColorPalette colors={['#FFFFFF', '#5A6973']} />
 * </ColorPicker>
 * @example
 * <ColorPicker onChangeComplete={() => {}} selectedColor={activeColor}>
 *   <ColorBuilder />
 *   <ColorInputPanel defaultColorFormat='hsl' />
 *   <ColorPalette label='Saved colors' colors={['#FFFFFF', '#5A6973']} />
 * </ColorPicker>
 */
export declare const ColorPicker: PolymorphicForwardRefComponent<"div", ColorPickerProps>;
export {};
