import * as React from 'react';
import { ColorValue, useMergedRefs, Box } from '../../utils/index.js';
import cx from 'classnames';
import { ColorPickerContext } from './ColorPickerContext.js';
export const getColorValue = (color) => {
  if (color instanceof ColorValue) return color;
  return ColorValue.create(color);
};
export const ColorPicker = React.forwardRef((props, forwardedRef) => {
  let {
    children,
    className,
    selectedColor,
    onChange,
    onChangeComplete,
    showAlpha = false,
    applyBackground = true,
    ...rest
  } = props;
  let ref = React.useRef(null);
  let inColor = React.useMemo(
    () => getColorValue(selectedColor),
    [selectedColor],
  );
  let activeColorTbgr = React.useRef(inColor.toTbgr());
  let [activeColor, setActiveColor] = React.useState(inColor);
  React.useEffect(() => {
    setActiveColor(inColor);
  }, [inColor]);
  let [hsvColor, setHsvColor] = React.useState(() => activeColor.toHsvColor());
  React.useEffect(() => {
    if (inColor.toTbgr() !== activeColorTbgr.current) {
      activeColorTbgr.current = inColor.toTbgr();
      setHsvColor(inColor.toHsvColor());
    }
  }, [inColor]);
  let applyHsvColorChange = React.useCallback(
    (newColor, selectionChanged, newColorValue) => {
      setHsvColor(newColor);
      let newActiveColor = newColorValue ?? ColorValue.create(newColor);
      if (selectionChanged) onChangeComplete?.(newActiveColor);
      else onChange?.(newActiveColor);
      activeColorTbgr.current = newActiveColor.toTbgr();
      setActiveColor(newActiveColor);
    },
    [onChange, onChangeComplete],
  );
  return React.createElement(
    Box,
    {
      className: cx(
        'iui-color-picker',
        {
          'iui-popover-surface': applyBackground,
        },
        className,
      ),
      ref: useMergedRefs(ref, forwardedRef),
      ...rest,
    },
    React.createElement(
      ColorPickerContext.Provider,
      {
        value: {
          activeColor,
          setActiveColor,
          hsvColor,
          applyHsvColorChange,
          onChangeComplete,
          showAlpha,
        },
      },
      children,
    ),
  );
});
if ('development' === process.env.NODE_ENV)
  ColorPicker.displayName = 'ColorPicker';
