import * as React from 'react';
import type { DialogContextProps } from './DialogContext.js';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type DialogProps = {
    /**
     * Dialog content.
     */
    children: React.ReactNode;
} & DialogContextProps;
/**
 * Dialog component.
 * @example
 * <Dialog
 *   isOpen={isOpen}
 *   onClose={() => setIsOpen(false)}
 *   trapFocus
 *   preventDocumentScroll
 * >
 *   <Dialog.Backdrop />
 *   <Dialog.Main aria-modal>
 *    <Dialog.TitleBar>My dialog title</Dialog.TitleBar>
 *    <Dialog.Content>
 *      Here is my dialog content
 *    </Dialog.Content>
 *    <Dialog.ButtonBar>
 *      <Button styleType='high-visibility'>Confirm</Button>
 *      <Button>Close</Button>
 *    </Dialog.ButtonBar>
 *   </Dialog.Main>
 * </Dialog>
 */
export declare const Dialog: PolymorphicForwardRefComponent<"div", DialogProps> & {
    Backdrop: PolymorphicForwardRefComponent<"div", import("../Backdrop/Backdrop.js").BackdropProps & Pick<DialogContextProps, "onClose" | "isDismissible" | "closeOnExternalClick" | "relativeTo">>;
    Main: PolymorphicForwardRefComponent<"div", import("./DialogMain.js").DialogMainProps>;
    TitleBar: PolymorphicForwardRefComponent<"div", {
        children?: React.ReactNode;
        titleText?: React.ReactNode;
    } & Pick<DialogContextProps, "onClose" | "isDismissible" | "isDraggable">> & {
        Title: PolymorphicForwardRefComponent<"div", {}>;
    };
    Content: PolymorphicForwardRefComponent<"div", {}>;
    ButtonBar: PolymorphicForwardRefComponent<"div", {}>;
};
export {};
