import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
import type { DialogContextProps } from './DialogContext.js';
export type DialogMainProps = {
    /**
     * Type of the dialog.
     * @default 'default'
     */
    styleType?: 'default' | 'fullPage';
    /**
     * Content of the dialog.
     */
    children: React.ReactNode;
} & Omit<DialogContextProps, 'closeOnExternalClick'>;
/**
 * Dialog component which can wrap any content.
 * @example
 * <Dialog.Main>
 *   <Dialog.TitleBar>
 *     My dialog title
 *   </Dialog.TitleBar>
 *   <Dialog.Content>
 *     Here is my dialog content
 *   </Dialog.Content>
 *   <Dialog.ButtonBar>
 *     <Button styleType='high-visibility'>
 *       Primary button
 *     </Button>
 *     <Button>
 *       Secondary button
 *     </Button>
 *   </Dialog.ButtonBar>
 * </Dialog.Main>
 */
export declare const DialogMain: PolymorphicForwardRefComponent<"div", DialogMainProps>;
