import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
import type { DialogContextProps } from './DialogContext.js';
type DialogTitleBarProps = {
    /**
     * Dialog title bar content. If passed, then `title` prop is ignored.
     */
    children?: React.ReactNode;
    /**
     * Dialog title.
     */
    titleText?: React.ReactNode;
} & Pick<DialogContextProps, 'isDismissible' | 'onClose' | 'isDraggable'>;
/**
 * Dialog title bar. Recommended to be used as a child of `Dialog`.
 * @example
 * <Dialog.TitleBar title='My dialog title' />
 * @example
 * <Dialog.TitleBar>
 *   <Dialog.TitleBar.Title>My dialog title</Dialog.TitleBar.Title>
 *   <IconButton
 *     size='small'
 *     styleType='borderless'
 *     onClick={onClose}
 *     aria-label='Close'
 *   >
 *     <SvgClose />
 *   </IconButton>
 * </Dialog.TitleBar>
 */
export declare const DialogTitleBar: PolymorphicForwardRefComponent<"div", DialogTitleBarProps> & {
    Title: PolymorphicForwardRefComponent<"div", {}>;
};
export {};
