import * as React from 'react';
import { Input } from '../Input/Input.js';
import { InputWithIcon, StatusIconMap } from '../../utils/index.js';
import { InputGrid } from '../InputGrid/InputGrid.js';
import { StatusMessage } from '../StatusMessage/StatusMessage.js';
import { Label } from '../Label/Label.js';
import { Icon } from '../Icon/Icon.js';
import cx from 'classnames';
export const LabeledInput = React.forwardRef((props, ref) => {
  let {
    disabled = false,
    label,
    message,
    status,
    svgIcon,
    wrapperProps,
    labelProps,
    messageContentProps,
    iconProps,
    inputWrapperProps,
    displayStyle = 'default',
    required = false,
    ...rest
  } = props;
  let icon = svgIcon ?? (status && StatusIconMap[status]());
  let shouldShowIcon = null !== svgIcon && (svgIcon || (status && !message));
  return React.createElement(
    InputGrid,
    {
      labelPlacement: displayStyle,
      'data-iui-status': status,
      ...wrapperProps,
    },
    label &&
      React.createElement(
        Label,
        {
          as: 'label',
          required: required,
          disabled: disabled,
          ...labelProps,
        },
        label,
      ),
    React.createElement(
      InputWithIcon,
      inputWrapperProps,
      React.createElement(Input, {
        disabled: disabled,
        required: required,
        ref: ref,
        ...rest,
      }),
      shouldShowIcon &&
        React.createElement(
          Icon,
          {
            fill: status,
            ...iconProps,
            className: cx('iui-end-icon', iconProps?.className),
          },
          icon,
        ),
    ),
    'string' == typeof message
      ? React.createElement(
          StatusMessage,
          {
            status: status,
            iconProps: iconProps,
            contentProps: messageContentProps,
          },
          message,
        )
      : message,
  );
});
if ('development' === process.env.NODE_ENV)
  LabeledInput.displayName = 'LabeledInput';
