import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type SkipToContentLinkProps = {
    /**
     * The id of the main content that the link directs to. Don't forget the #!
     */
    href: string;
    /**
     * Localize 'Skip to main content' label.
     * @default 'Skip to main content'
     */
    children?: React.ReactNode;
};
/**
 * `SkipToContentLink` is for screen reader and keyboard users and will not be visible unless tabbed to.
 * Provides a shortcut to the main content of the page without navigating through the header, etc.
 * Should be placed just inside the body. Set `href` to the id of your main content component. Don't forget the `#`!
 * @example
 * <body><SkipToContentLink href='#main-content-id' /> ... </body>
 * <body><SkipToContentLink href='#main-content-id'>{localizedLabel}</SkipToContentLink> ... </body>
 */
export declare const SkipToContentLink: PolymorphicForwardRefComponent<"a", SkipToContentLinkProps>;
export {};
