import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
export type StepperStepProps = {
    /**
     * The title/label of the step.
     */
    title: string;
    /**
     * the index of this step, 0-based.
     */
    index: number;
    /**
     * the Stepper's current step number, 0-based.
     */
    currentStepNumber: number;
    /**
     * number of total steps in the stepper.
     */
    totalSteps: number;
    /**
     * Stepper type.
     */
    type: 'default' | 'long';
    /**
     *  Click handler on completed step.
     */
    onClick?: (clickedIndex: number) => void;
    /**
     * A tooltip giving detailed description to this step.
     */
    description?: string;
    /**
     * Custom content displayed in the step's circle.
     */
    stepContent?: () => React.ReactNode;
    /**
     * Allows props to be passed for stepper step.
     */
    stepProps?: React.ComponentProps<'li'>;
    /**
     * Allows props to be passed for track content.
     */
    trackContentProps?: React.ComponentProps<'div'>;
    /**
     * Allows props to be passed for stepper-step circle.
     */
    circleProps?: React.ComponentProps<'span'>;
    /**
     * Allows props to be passed for stepper name.
     */
    nameProps?: React.ComponentProps<'span'>;
};
export declare const StepperStep: PolymorphicForwardRefComponent<"li", StepperStepProps>;
