import * as React from 'react';
import { useGlobals } from '../../../../utils/index.js';
import { FilterButtonBar } from '../FilterButtonBar.js';
import { BaseFilter } from '../BaseFilter.js';
import { DatePickerInput } from './DatePickerInput.js';
let defaultStrings = {
  from: 'From',
  to: 'To',
};
let defaultFormatDate = (date) => {
  let formatter = new Intl.DateTimeFormat('en-us', {
    month: 'short',
    day: 'numeric',
    year: 'numeric',
  });
  return formatter.format(date);
};
let defaultParseInput = (text) => {
  if (/^[a-z]{3}\s\d{1,2},\s\d{4}$/gi.test(text)) return new Date(text);
  return new Date('');
};
export const DateRangeFilter = (props) => {
  let {
    column,
    translatedLabels,
    setFilter,
    clearFilter,
    formatDate = defaultFormatDate,
    parseInput = defaultParseInput,
    placeholder = 'MMM dd, yyyy',
    showYearSelection,
  } = props;
  useGlobals();
  let translatedStrings = {
    ...defaultStrings,
    ...translatedLabels,
  };
  let [from, setFrom] = React.useState(
    column.filterValue?.[0] ? new Date(column.filterValue?.[0]) : void 0,
  );
  let inputRef = React.useRef(null);
  React.useEffect(() => {
    if (inputRef.current) inputRef.current.focus();
  }, []);
  let onFromChange = React.useCallback((date) => {
    setFrom((prevDate) => {
      if (prevDate || !date) return date;
      return new Date(
        date.getFullYear(),
        date.getMonth(),
        date.getDate(),
        0,
        0,
        0,
        0,
      );
    });
  }, []);
  let [to, setTo] = React.useState(
    column.filterValue?.[1] ? new Date(column.filterValue?.[1]) : void 0,
  );
  let onToChange = React.useCallback((date) => {
    setTo((prevDate) => {
      if (prevDate || !date) return date;
      return new Date(
        date.getFullYear(),
        date.getMonth(),
        date.getDate(),
        23,
        59,
        59,
        999,
      );
    });
  }, []);
  return React.createElement(
    BaseFilter,
    {
      onSubmit: () => setFilter([from, to]),
    },
    React.createElement(DatePickerInput, {
      ref: inputRef,
      label: translatedStrings.from,
      date: from,
      onChange: onFromChange,
      formatDate: formatDate,
      parseInput: parseInput,
      placeholder: placeholder,
      selectedDate: to,
      isFromOrTo: 'from',
      localizedNames: translatedStrings.datePicker,
      showYearSelection: showYearSelection,
    }),
    React.createElement(DatePickerInput, {
      label: translatedStrings.to,
      date: to,
      onChange: onToChange,
      formatDate: formatDate,
      parseInput: parseInput,
      placeholder: placeholder,
      selectedDate: from,
      isFromOrTo: 'to',
      localizedNames: translatedStrings.datePicker,
      showYearSelection: showYearSelection,
    }),
    React.createElement(FilterButtonBar, {
      clearFilter: clearFilter,
      translatedLabels: translatedLabels,
    }),
  );
};
