import * as React from 'react';
import { useGlobals } from '../../../../utils/index.js';
import { FilterButtonBar } from '../FilterButtonBar.js';
import { BaseFilter } from '../BaseFilter.js';
import { LabeledInput } from '../../../LabeledInput/LabeledInput.js';
let defaultStrings = {
  from: 'From',
  to: 'To',
};
export const NumberRangeFilter = (props) => {
  let { column, translatedLabels, setFilter, clearFilter } = props;
  useGlobals();
  let translatedStrings = {
    ...defaultStrings,
    ...translatedLabels,
  };
  let inputRef = React.useRef(null);
  React.useEffect(() => {
    if (inputRef.current) inputRef.current.focus();
  }, []);
  let [from, setFrom] = React.useState(column.filterValue?.[0] ?? '');
  let [to, setTo] = React.useState(column.filterValue?.[1] ?? '');
  let parseInputValue = (value) =>
    !value || isNaN(Number(value)) ? void 0 : Number(value);
  return React.createElement(
    BaseFilter,
    {
      onSubmit: () => setFilter([parseInputValue(from), parseInputValue(to)]),
    },
    React.createElement(LabeledInput, {
      ref: inputRef,
      label: translatedStrings.from,
      value: from,
      onChange: (e) => setFrom(e.target.value),
      type: 'number',
      displayStyle: 'inline',
    }),
    React.createElement(LabeledInput, {
      label: translatedStrings.to,
      value: to,
      onChange: (e) => setTo(e.target.value),
      type: 'number',
      displayStyle: 'inline',
    }),
    React.createElement(FilterButtonBar, {
      clearFilter: clearFilter,
      translatedLabels: translatedLabels,
    }),
  );
};
