import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type TagProps = {
    /**
     * Text inside the tag.
     */
    children: React.ReactNode;
    /**
     * Callback invoked when the tag is clicked.
     *
     * When this prop is passed, the tag will be rendered as a button.
     */
    onClick?: React.MouseEventHandler;
    /**
     * Callback function that handles click on the remove ("❌") button.
     * If not passed, the remove button will not be shown.
     *
     * If both `onClick` and `onRemove` are passed, then the tag label (rather than the tag itself)
     * will be rendered as a button, to avoid invalid markup (nested buttons).
     */
    onRemove?: React.MouseEventHandler;
    /**
     * Props for customizing the remove ("❌") button.
     */
    removeButtonProps?: React.ComponentPropsWithRef<'button'>;
} & ({
    /**
     * Variant of tag.
     * Basic tags don't have an outline.
     * @default 'default'
     */
    variant?: 'default';
    /**
     * Props for customizing the label.
     *
     * Only relevant for the 'default' Tag.
     */
    labelProps?: React.ComponentPropsWithRef<'span'>;
} | {
    variant?: 'basic';
    labelProps?: never;
});
/**
 * Tag for showing categories, filters etc.
 * @example
 * <Tag onRemove={() => alert('Closed a tag!')}>I'm a tag</Tag>
 * <Tag variant='basic'>Basic tag</Tag>
 */
export declare const Tag: PolymorphicForwardRefComponent<"span", TagProps>;
export {};
