import cx from 'classnames';
import * as React from 'react';
import {
  SvgCloseSmall,
  Box,
  ButtonBase,
  mergeEventHandlers,
} from '../../utils/index.js';
import { IconButton } from '../Buttons/IconButton.js';
import { LinkAction, LinkBox } from '../LinkAction/LinkAction.js';
export const Tag = React.forwardRef((props, forwardedRef) => {
  let {
    className,
    variant = 'default',
    children,
    onRemove,
    onClick,
    labelProps,
    removeButtonProps,
    ...rest
  } = props;
  let shouldUseLinkAction = !!onClick && !!onRemove;
  return React.createElement(
    Box,
    {
      as: shouldUseLinkAction ? LinkBox : onClick ? ButtonBase : 'span',
      className: cx(
        {
          'iui-tag-basic': 'basic' === variant,
          'iui-tag': 'default' === variant,
        },
        className,
      ),
      ref: forwardedRef,
      onClick: shouldUseLinkAction ? void 0 : onClick,
      ...rest,
    },
    'default' === variant
      ? React.createElement(
          Box,
          {
            as: shouldUseLinkAction ? LinkAction : 'span',
            ...labelProps,
            onClick: mergeEventHandlers(
              labelProps?.onClick,
              shouldUseLinkAction ? onClick : void 0,
            ),
            className: cx('iui-tag-label', labelProps?.className),
          },
          children,
        )
      : children,
    onRemove &&
      React.createElement(
        IconButton,
        {
          styleType: 'borderless',
          size: 'small',
          'aria-label': 'Delete tag',
          ...removeButtonProps,
          onClick: mergeEventHandlers(removeButtonProps?.onClick, onRemove),
          className: cx('iui-tag-button', removeButtonProps?.className),
        },
        React.createElement(SvgCloseSmall, {
          'aria-hidden': true,
        }),
      ),
  );
});
if ('development' === process.env.NODE_ENV) Tag.displayName = 'Tag';
