import * as React from 'react';
import type { PolymorphicForwardRefComponent } from '../../utils/index.js';
type TagContainerProps = {
    /**
     * Tags inside the container.
     */
    children: React.ReactNode;
    /**
     * Overflow solution to the tag container.
     * Set max-width to have scroll or truncated tags.
     */
    overflow?: 'truncate' | 'scroll';
    /**
     * Use background to have tags standout in your layout.
     * Container gets colored background and some spacing applied.
     * @default 'none'
     */
    background?: 'none' | 'filled';
};
/**
 * TagContainer for grouping tags.
 * @example
 * <TagContainer><Tag>Tag 1</Tag><Tag>Tag 2</Tag></TagContainer>
 * <TagContainer><Tag variant='basic'>Basic tag</Tag><Tag variant='basic'>Basic tag 2</Tag></TagContainer>
 */
export declare const TagContainer: PolymorphicForwardRefComponent<"div", TagContainerProps>;
export {};
