import type { PolymorphicForwardRefComponent } from '../props.js';
import type { IconProps } from '../../core/Icon/Icon.js';
import type { IconButtonProps } from '../../core/Buttons/IconButton.js';
export type InputFlexContainerProps = {
    isDisabled?: boolean;
    status?: 'positive' | 'warning' | 'negative';
    size?: 'small' | 'large';
};
/**
 * Utility component for input container with display flex abilities.
 * @private
 */
export declare const InputFlexContainer: PolymorphicForwardRefComponent<"div", InputFlexContainerProps>;
/**
 * Button inside InputFlexContainer that collapses the padding between the button and the input/textarea.
 * @private
 */
export declare const InputFlexContainerButton: PolymorphicForwardRefComponent<"button", Omit<IconButtonProps, "styleType"> & {
    /**
     * Style of the button.
     * Use 'borderless' to hide outline.
     * @default 'borderless'
     */
    styleType?: IconButtonProps["styleType"];
}>;
/**
 * Icon inside InputFlexContainer that collapses the padding between the icon and the input/textarea.
 * @private
 */
export declare const InputFlexContainerIcon: PolymorphicForwardRefComponent<"span", Omit<IconProps, "padded"> & {
    /**
     * Option to add padding to the icon.
     * @default true
     */
    padded?: IconProps["padded"];
}>;
